# -*- coding: utf-8 -*-
#
# File: browser.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Ramon Bartl <ramon.bartl@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 60982 $"
__version__   = '$Revision: 60982 $'[11:-2]

from plone.fieldsets.fieldsets import FormFieldsets
from Products.Five.formlib import formbase
from Products.Five.browser import BrowserView

from collective.gacontext.interfaces import IGACode
from collective.gacontext.interfaces import IGAContextMarker

class GAForm(formbase.EditForm):
    """ Edit annotations form """
    form_fields = FormFieldsets(IGACode)


class GACondition(BrowserView):
    """Returns True or False depending on whether the current context is GA aware.
    """
    @property
    def _action_condition(self):
        context = self.context
        return IGAContextMarker.providedBy(context)

    def __call__(self):
        return self._action_condition

# vim: set ft=python ts=4 sw=4 expandtab :
